# stubwheel
a script that reserves a project name on pypi

## installation
```sh
pip install stubwheel
```

## usage
```sh
stubwheel.py --name <PACKAGE_NAME>
```
#### other options:
```sh
stubwheel.py --help
```
```
  -h, --help         show this help message and exit
  --name NAME        package name (required)
  --version VERSION  package version (optional)
  --url URL          package url (optional)
  --author AUTHOR    author name (optional)
  --email EMAIL      author email (optional)
  --desc DESC        package description (optional)
```
